[−][src]Struct exonum_testkit::TestNetworkConfiguration
A configuration of the test network.
Methods
impl TestNetworkConfiguration[src]
pub fn us(&self) -> &TestNode[src]
Returns the node from whose perspective the testkit operates.
pub fn set_us(&mut self, us: TestNode)[src]
Modifies the node from whose perspective the testkit operates.
pub fn validators(&self) -> &[TestNode][src]
Returns the test network validators.
pub fn consensus_configuration(&self) -> &ConsensusConfig[src]
Returns the current consensus configuration.
pub fn actual_from(&self) -> Height[src]
Return the height, starting from which this configuration becomes actual.
pub fn set_actual_from(&mut self, actual_from: Height)[src]
Modifies the height, starting from which this configuration becomes actual.
pub fn set_consensus_configuration(&mut self, consensus: ConsensusConfig)[src]
Modifies the current consensus configuration.
pub fn set_validators<I>(&mut self, validators: I) where
I: IntoIterator<Item = TestNode>, [src]
I: IntoIterator<Item = TestNode>,
Modifies the validators list.
pub fn service_config<D>(&self, id: &str) -> D where
D: Deserialize<'de>, [src]
D: Deserialize<'de>,
Returns the configuration for service with the given identifier.
pub fn set_service_config<D>(&mut self, id: &str, config: D) where
D: Serialize, [src]
D: Serialize,
Modifies the configuration of the service with the given identifier.
pub fn stored_configuration(&self) -> &StoredConfiguration[src]
Returns the resulting exonum blockchain configuration.